==> SnappEmailApiClient-0.3.7.zip: SnappEmailApiClient-0.3.7/snapp_email/endpoints/user_settings/GMailSyncInfo_16Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import GMailSyncInfo_16
from snapp_email.datacontract.utils import export_dict, fill


class GMailSyncInfo_16Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'GMailSyncInfo_16'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: GMailSyncInfo_16
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'user/settings'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.gmail.sync.info-5.2+json',
            'Accept': 'application/vnd.4thoffice.gmail.sync.info-5.2+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(GMailSyncInfo_16, response.json())
    
    def get(self, accept_type=None):
        """
        Get sync info resource.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: GMailSyncInfo_16
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'user/settings'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.gmail.sync.info-5.2+json',
            'Accept': 'application/vnd.4thoffice.gmail.sync.info-5.2+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers)
        
        return fill(GMailSyncInfo_16, response.json())

==> SnappEmailApiClient-0.3.16.zip: SnappEmailApiClient-0.3.16/snapp_email/endpoints/user_settings/GMailSyncInfo_16Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import GMailSyncInfo_16
from snapp_email.datacontract.utils import export_dict, fill


class GMailSyncInfo_16Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'GMailSyncInfo_16'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: GMailSyncInfo_16
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'user/settings'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.gmail.sync.info-5.2+json',
            'Accept': 'application/vnd.4thoffice.gmail.sync.info-5.2+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(GMailSyncInfo_16, response.json())
    
    def get(self, impersonate_user_id=None, accept_type=None):
        """
        Get sync info resource.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: GMailSyncInfo_16
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'user/settings'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.gmail.sync.info-5.2+json',
            'Accept': 'application/vnd.4thoffice.gmail.sync.info-5.2+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(GMailSyncInfo_16, response.json())
